mailr20861 - /branches/relax_disp/gui/components/spectrum.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on September 05, 2013 - 18:56:
Author: bugman
Date: Thu Sep  5 18:56:33 2013
New Revision: 20861

URL: http://svn.gna.org/viewcvs/relax?rev=20861&view=rev
Log:
Fix for the relax_disp.exp_type pop up menu entry in the spectrum list GUI 
element.

This was calling relax_fit.exp_type rather than relax_disp.exp_type.


Modified:
    branches/relax_disp/gui/components/spectrum.py

Modified: branches/relax_disp/gui/components/spectrum.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/gui/components/spectrum.py?rev=20861&r1=20860&r2=20861&view=diff
==============================================================================
--- branches/relax_disp/gui/components/spectrum.py (original)
+++ branches/relax_disp/gui/components/spectrum.py Thu Sep  5 18:56:33 2013
@@ -109,8 +109,8 @@
             uf_store['relax_disp.cpmg_frq'](frq=frq, spectrum_id=id)
 
 
-    def action_relax_fit_exp_type(self, event):
-        """Launch the relax_fit.exp_type user function.
+    def action_relax_disp_exp_type(self, event):
+        """Launch the relax_disp.exp_type user function.
 
         @param event:   The wx event.
         @type event:    wx event
@@ -129,9 +129,9 @@
 
         # Launch the dialog.
         if exp_type == None:
-            uf_store['relax_fit.exp_type'](spectrum_id=id)
+            uf_store['relax_disp.exp_type'](spectrum_id=id)
         else:
-            uf_store['relax_fit.exp_type'](spectrum_id=id, exp_type=exp_type)
+            uf_store['relax_disp.exp_type'](spectrum_id=id, 
exp_type=exp_type)
 
 
     def action_relax_disp_spin_lock_field(self, event):
@@ -559,7 +559,7 @@
                 'id': wx.NewId(),
                 'text': "Set the &experiment type",
                 'icon': None,
-                'method': self.action_relax_fit_exp_type
+                'method': self.action_relax_disp_exp_type
             })
         if self.relax_times_flag:
             self.popup_menus.append({




Related Messages


Powered by MHonArc, Updated Thu Sep 05 19:20:02 2013